@@ -1,4 +1,4 @@
-__version__ = "1.0.0"
+__version__ = "1.1.1"
 
 from .models import \
     RQModel, RQComputedModel, \
@@ -21,7 +21,8 @@ from .widgets import \
     RQSlider, \
     RQDial, \
     RQDoubleSpinBox, \
-    RQWidgetObject
+    RQWidgetObject, \
+    RQPushButton
 
 from .layouts import \
     RQBoxLayout, \
@@ -29,3 +30,4 @@ from .layouts import \
     RQHBoxLayout
 
 from .rq_getattr import rq_getattr
+from .rq_getlist import rq_getlist
